@@ -4,46 +4,50 @@ import warnings
 
 import numpy as np
 from numpy.testing import assert_array_almost_equal
-import bottleneck as bn  # noqa
-from .functions import all_functions
+import bottleneck as bn
+from .util import DTYPES
 
 
-def lists():
+def test_list_input():
+    "Check that functions can handle list input"
+    for func in bn.get_functions('all'):
+        if func.__name__ != 'replace':
+            yield unit_maker, func
+
+
+def lists(dtypes=DTYPES):
     "Iterator that yields lists to use for unit testing."
     ss = {}
     ss[1] = {'size':  4, 'shapes': [(4,)]}
     ss[2] = {'size':  6, 'shapes': [(1, 6), (2, 3)]}
     ss[3] = {'size':  6, 'shapes': [(1, 2, 3)]}
-    ss[4] = {'size': 24, 'shapes': [(1, 2, 3, 4)]}  # Unaccelerated
+    ss[4] = {'size': 24, 'shapes': [(1, 2, 3, 4)]}
     for ndim in ss:
         size = ss[ndim]['size']
         shapes = ss[ndim]['shapes']
         a = np.arange(size)
         for shape in shapes:
             a = a.reshape(shape)
-            yield a.tolist()
+            for dtype in dtypes:
+                yield a.astype(dtype).tolist()
 
 
-def unit_maker(func, func0):
+def unit_maker(func):
     "Test that bn.xxx gives the same output as bn.slow.xxx for list input."
-    msg = '\nfunc %s | input %s | shape %s\n'
+    msg = '\nfunc %s | input %s (%s) | shape %s\n'
     msg += '\nInput array:\n%s\n'
-    for i, arr in enumerate(lists()):
+    name = func.__name__
+    func0 = eval('bn.slow.%s' % name)
+    for i, a in enumerate(lists()):
         with warnings.catch_warnings():
             warnings.simplefilter("ignore")
             try:
-                actual = func(arr)
-                desired = func0(arr)
+                actual = func(a)
+                desired = func0(a)
             except TypeError:
-                actual = func(arr, 2)
-                desired = func0(arr, 2)
-        tup = (func.__name__, 'a'+str(i), str(np.array(arr).shape), arr)
+                actual = func(a, 2)
+                desired = func0(a, 2)
+        a = np.array(a)
+        tup = (name, 'a'+str(i), str(a.dtype), str(a.shape), a)
         err_msg = msg % tup
         assert_array_almost_equal(actual, desired, err_msg=err_msg)
-
-
-def test_list_input():
-    "Check that functions can handle list input"
-    for func in all_functions():
-        if func.__name__ != 'replace':
-            yield unit_maker, func, eval('bn.slow.%s' % func.__name__)
